/* the packages name */
#undef PACKAGE

/* the package version */
#undef VERSION

/* define if you have the readline library */
#undef HAVE_LIBREADLINE

/* define if you want debugging messages */
#undef DEBUG

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

#undef NEED_herror_PROTO

#undef NEED_vasprintf_PROTO

#undef NEED_asprintf_PROTO

#undef HAVE_BSD_SIGNALS

#undef HAVE_POSIX_SIGNALS

#undef HAVE_POSIX_SIGSETJMP

#undef HAVE_USG_SIGHOLD

#undef HAVE_REGEX

#undef KRB4

#undef KRB5

#undef USE_SSL

/* Define this if we're using MIT's implementation of krb5 */
#undef KRB5_MIT

/* Define this if we're using the Heimdal implementation of krb5 */
#undef KRB5_HEIMDAL

#undef HAVE_LIBDES

#undef HOSTTYPE

#undef HAVE_U_INTXX_T

#undef HAVE_UINTXX_T

#undef HAVE_U_INT64_T

#undef HAVE_UINT64_T

#undef USE_PIPES
